**Status:** Maintenance (expect bug fixes and minor updates)

Stochastic Differential Equations Reinforcement Learning 
==================================

(RL) is a machine learning approach for teaching agents how to solve tasks by trial and error. Deep RL refers to the combination of RL with [deep learning](http://ufldl.stanford.edu/tutorial/).

Stochastic Differential Equations are used to model world phenomena with randomness. 

SDERL is an effort to combine those two concepts in one place through the general model-based reinforcement learning framework.
